Module trace_attributes

Module trace_attributes 

Models connected to the trace_attributes map-matching API Models connected to the trace_attributes map-matching API

See https://valhalla.github.io/valhalla/api/map-matching/api-reference/ for details.

Re-exports

pub use crate::shapes::ShapePoint;

Structs

Edge
A matched edge in the trace_attributes response.
EdgeSign
Sign information associated with an edge.
Filter
Filter to include or exclude specific attributes in the response.
Manifest
Request manifest for the trace_attributes API.
MatchedPoint
A matched point in the trace_attributes response.
Response
Response from the trace_attributes API.
SignElement
A single element on a sign.
TraceOptions
Options to fine-tune the GPS trace matching algorithm.
TracePoint
A shape point for the trace_attributes request.

Enums

EdgeUse
Use type of an edge.
FilterAction
Whether to include or exclude filtered attributes.
RoadClass
Road classification of an edge.
ShapeMatch
How to match the shape to the road network.
Surface
Surface type of a road edge.