pub enum ShapeMatch {
WalkOrSnap,
MapSnap,
EdgeWalk,
}Expand description
How to match the shape to the road network.
Variants
WalkOrSnap
Try edge walking first, fall back to map matching
MapSnap
Use map matching algorithm
EdgeWalk
Use edge walking algorithm (requires very precise input)