Edge

Struct Edge 

pub struct Edge {
Show 19 fields pub surface: Option<Surface>, pub road_class: Option<RoadClass>, pub use: Option<EdgeUse>, pub length: Option<f64>, pub names: Option<Vec<String>>, pub begin_shape_index: Option<u32>, pub end_shape_index: Option<u32>, pub way_id: Option<u64>, pub source_percent_along: Option<f64>, pub target_percent_along: Option<f64>, pub begin_heading: Option<f64>, pub end_heading: Option<f64>, pub speed: Option<f64>, pub toll: Option<bool>, pub tunnel: Option<bool>, pub bridge: Option<bool>, pub roundabout: Option<bool>, pub internal_intersection: Option<bool>, pub sign: Option<EdgeSign>,
}
A matched edge in the trace_attributes response.

Fields

surface: Option<Surface>

Road surface type

road_class: Option<RoadClass>

Road classification

use: Option<EdgeUse>

Edge use type

length: Option<f64>

Length of the edge in the response units (km or miles)

names: Option<Vec<String>>

Road names

begin_shape_index: Option<u32>

Index into the response shape where this edge begins

end_shape_index: Option<u32>

Index into the response shape where this edge ends

way_id: Option<u64>

OSM way ID

source_percent_along: Option<f64>

Percentage along the edge where the source point lies (first edge only)

target_percent_along: Option<f64>

Percentage along the edge where the target point lies (last edge only)

begin_heading: Option<f64>

Heading at the start of the edge in degrees (0-360)

end_heading: Option<f64>

Heading at the end of the edge in degrees (0-360)

speed: Option<f64>

Speed in kph along the edge

toll: Option<bool>

true if a toll booth is encountered on this edge

tunnel: Option<bool>

true if a tunnel is encountered on this edge

bridge: Option<bool>

true if a bridge is encountered on this edge

roundabout: Option<bool>

true if this edge is part of a roundabout

internal_intersection: Option<bool>

true if this edge is an internal intersection edge

sign: Option<EdgeSign>

The number of signs on the edge