Manifest

Struct Manifest 

pub struct Manifest { /* private fields */ }
Request manifest for the trace_attributes API.

Implementations

Source

impl Manifest

pub fn builder( shape: impl IntoIterator<Item = TracePoint>, costing: Costing, ) -> Self

Create a builder with the given shape points and costing.

pub fn builder_encoded( encoded_polyline: impl ToString, costing: Costing, ) -> Self

Create a builder with an encoded polyline and costing.

See Self::shape_format to set the precision of the polyline.

pub fn shape_match(self, shape_match: ShapeMatch) -> Self

Set the shape matching mode.

pub fn shape_format(self, shape_format: ShapeFormat) -> Self

Specifies whether the polyline is encoded with

Default: ShapeFormat::Polyline6

pub fn include_attributes( self, attributes: impl IntoIterator<Item = impl Into<String>>, ) -> Self

Set the attribute filter to include specific edge attributes.

pub fn exclude_attributes( self, attributes: impl IntoIterator<Item = impl Into<String>>, ) -> Self

Set the attribute filter to exclude specific edge attributes.

pub fn trace_options(self, trace_options: TraceOptions) -> Self

Set trace matching algorithm options.

pub fn units(self, units: Units) -> Self

Sets the distance units for output.

Default: super::Units::Metric

pub fn id(self, id: impl ToString) -> Self

Name of the request.

If id is specified, the naming will be sent through to the response.

pub fn language(self, language: impl ToString) -> Self

The language of the narration instructions based on the IETF BCP 47 language tag string.

Default: en-US

pub fn durations(self, durations: impl IntoIterator<Item = f64>) -> Self

Set durations in seconds between successive input points.

When provided along with Self::use_timestamps, Valhalla can use timing information to improve matching accuracy.

pub fn use_timestamps(self, use_timestamps: bool) -> Self

Whether to use timestamps/durations for the trace matching.

Default: false

pub fn begin_time(self, begin_time: impl ToString) -> Self

Set the begin time for the trace in the format YYYY-MM-DDTHH:MM.

Used together with Self::durations and Self::use_timestamps.