pub struct TraceOptions {
pub search_radius: Option<f64>,
pub gps_accuracy: Option<f64>,
pub breakage_distance: Option<f64>,
pub interpolation_distance: Option<f64>,
}Expand description
Options to fine-tune the GPS trace matching algorithm.
Fields
search_radius: Option<f64>Search radius in meters around each input point within which to search for candidate edges.
Default: 25
gps_accuracy: Option<f64>GPS accuracy in meters for the input points.
Default: 5
breakage_distance: Option<f64>Distance in meters beyond which a new breakage will be created.
Default: 2000
interpolation_distance: Option<f64>Distance in meters to interpolate between input points.
Default: 10