Models connected to the trace_attributes map-matching API
Models connected to the trace_attributes map-matching API
See https://valhalla.github.io/valhalla/api/map-matching/api-reference/ for details.
Re-exports
pub use crate::shapes::ShapePoint;
Structs
- Edge
- A matched edge in the trace_attributes response.
- Edge
Sign - Sign information associated with an edge.
- Filter
- Filter to include or exclude specific attributes in the response.
- Manifest
- Request manifest for the trace_attributes API.
- Matched
Point - A matched point in the trace_attributes response.
- Response
- Response from the trace_attributes API.
- Sign
Element - A single element on a sign.
- Trace
Options - Options to fine-tune the GPS trace matching algorithm.
- Trace
Point - A shape point for the trace_attributes request.
Enums
- EdgeUse
- Use type of an edge.
- Filter
Action - Whether to include or exclude filtered attributes.
- Road
Class - Road classification of an edge.
- Shape
Match - How to match the shape to the road network.
- Surface
- Surface type of a road edge.