pub struct Edge {
pub surface: Option<Surface>,
pub road_class: Option<RoadClass>,
pub use: Option<EdgeUse>,
pub length: Option<f64>,
pub names: Option<Vec<String>>,
pub begin_shape_index: Option<u32>,
pub end_shape_index: Option<u32>,
pub way_id: Option<u64>,
pub source_percent_along: Option<f64>,
pub target_percent_along: Option<f64>,
}Expand description
A matched edge in the trace_attributes response.
Fields
surface: Option<Surface>Road surface type
road_class: Option<RoadClass>Road classification
use: Option<EdgeUse>Edge use type
length: Option<f64>Length of the edge in the response units (km or miles)
names: Option<Vec<String>>Road names
begin_shape_index: Option<u32>Index into the response shape where this edge begins
end_shape_index: Option<u32>Index into the response shape where this edge ends
way_id: Option<u64>OSM way ID
source_percent_along: Option<f64>Percentage along the edge where the source point lies (first edge only)
target_percent_along: Option<f64>Percentage along the edge where the target point lies (last edge only)