pub struct Manifest { /* private fields */ }Expand description
Request manifest for the trace_attributes API.
Implementations
Sourceimpl Manifest
impl Manifest
Sourcepub fn builder(
shape: impl IntoIterator<Item = TracePoint>,
costing: Costing,
) -> Self
pub fn builder( shape: impl IntoIterator<Item = TracePoint>, costing: Costing, ) -> Self
Create a builder with the given shape points and costing.
Sourcepub fn builder_encoded(
encoded_polyline: impl ToString,
costing: Costing,
) -> Self
pub fn builder_encoded( encoded_polyline: impl ToString, costing: Costing, ) -> Self
Create a builder with an encoded polyline and costing.
See Self::shape_format to set the precision of the polyline.
Sourcepub fn shape_match(self, shape_match: ShapeMatch) -> Self
pub fn shape_match(self, shape_match: ShapeMatch) -> Self
Set the shape matching mode.
Sourcepub fn shape_format(self, shape_format: ShapeFormat) -> Self
pub fn shape_format(self, shape_format: ShapeFormat) -> Self
Specifies whether the polyline is encoded with
- 6 digit precision (
ShapeFormat::Polyline6) or - 5 digit precision (
ShapeFormat::Polyline5).
Default: ShapeFormat::Polyline6
Sourcepub fn include_attributes(
self,
attributes: impl IntoIterator<Item = impl Into<String>>,
) -> Self
pub fn include_attributes( self, attributes: impl IntoIterator<Item = impl Into<String>>, ) -> Self
Set the attribute filter to include specific edge attributes.
Sourcepub fn exclude_attributes(
self,
attributes: impl IntoIterator<Item = impl Into<String>>,
) -> Self
pub fn exclude_attributes( self, attributes: impl IntoIterator<Item = impl Into<String>>, ) -> Self
Set the attribute filter to exclude specific edge attributes.
Sourcepub fn trace_options(self, trace_options: TraceOptions) -> Self
pub fn trace_options(self, trace_options: TraceOptions) -> Self
Set trace matching algorithm options.
Sourcepub fn units(self, units: Units) -> Self
pub fn units(self, units: Units) -> Self
Sets the distance units for output.
Default: super::Units::Metric
Sourcepub fn id(self, id: impl ToString) -> Self
pub fn id(self, id: impl ToString) -> Self
Name of the request.
If id is specified, the naming will be sent through to the response.
Sourcepub fn language(self, language: impl ToString) -> Self
pub fn language(self, language: impl ToString) -> Self
The language of the narration instructions based on the IETF BCP 47 language tag string.
Default: en-US
Sourcepub fn durations(self, durations: impl IntoIterator<Item = f64>) -> Self
pub fn durations(self, durations: impl IntoIterator<Item = f64>) -> Self
Set durations in seconds between successive input points.
When provided along with Self::use_timestamps, Valhalla can use timing
information to improve matching accuracy.
Sourcepub fn use_timestamps(self, use_timestamps: bool) -> Self
pub fn use_timestamps(self, use_timestamps: bool) -> Self
Whether to use timestamps/durations for the trace matching.
Default: false
Sourcepub fn begin_time(self, begin_time: impl ToString) -> Self
pub fn begin_time(self, begin_time: impl ToString) -> Self
Set the begin time for the trace in the format YYYY-MM-DDTHH:MM.
Used together with Self::durations and Self::use_timestamps.